[llvm-commits] CVS: llvm/include/llvm/CodeGen/MachineInstr.h

Evan Cheng evan.cheng at apple.com
Tue May 29 11:31:23 PDT 2007



Changes in directory llvm/include/llvm/CodeGen:

MachineInstr.h updated: 1.220 -> 1.221
---
Log message:

Add missing const qualifiers.

---
Diffs of the changes:  (+5 -4)

 MachineInstr.h |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)


Index: llvm/include/llvm/CodeGen/MachineInstr.h
diff -u llvm/include/llvm/CodeGen/MachineInstr.h:1.220 llvm/include/llvm/CodeGen/MachineInstr.h:1.221
--- llvm/include/llvm/CodeGen/MachineInstr.h:1.220	Wed May 16 15:43:42 2007
+++ llvm/include/llvm/CodeGen/MachineInstr.h	Tue May 29 13:30:54 2007
@@ -415,15 +415,16 @@
   /// findRegisterUseOperandIdx() - Returns the operand index that is a use of
   /// the specific register or -1 if it is not found. It further tightening
   /// the search criteria to a use that kills the register if isKill is true.
-  int findRegisterUseOperandIdx(unsigned Reg, bool isKill = false);
+  int findRegisterUseOperandIdx(unsigned Reg, bool isKill = false) const;
   
   /// findRegisterDefOperand() - Returns the MachineOperand that is a def of
   /// the specific register or NULL if it is not found.
   MachineOperand *findRegisterDefOperand(unsigned Reg);
 
-  /// findFirstPredOperand() - Find the first operand in the operand list that
-  // is used to represent the predicate.
-  MachineOperand *findFirstPredOperand();
+  /// findFirstPredOperandIdx() - Find the index of the first operand in the
+  /// operand list that is used to represent the predicate. It returns -1 if
+  /// none is found.
+  int findFirstPredOperandIdx() const;
   
   /// copyKillDeadInfo - Copies kill / dead operand properties from MI.
   ///






More information about the llvm-commits mailing list